@@ -9,7 +9,9 @@ class Command(BaseCommand):
             "command", nargs="?", default="all", type=str, choices=list(COMMANDS_BY_NAME.keys())
         )
         parser.add_argument(
-            "--background", action="store_true", help="Run import job in background using Celery",
+            "--background",
+            action="store_true",
+            help="Run import job in background using Celery",
         )
 
     def handle(self, *args, **options):
