@@ -1,4 +1,5 @@
 import logging
+import re
 from datetime import time
 from enum import Enum
 from typing import Dict
@@ -179,7 +180,7 @@ def import_classes(
         # Build values
         short_name = class_.name[:16]
         name = class_.longname if class_.longname else short_name
-        teacher_ids = untis_split_first(class_.teacherids, int)
+        teacher_ids = untis_split_first(class_.teacherids, int) if class_.teacherids else []
         owners = [teachers_ref[t_id] for t_id in teacher_ids]
         import_ref = class_.class_id
 
@@ -187,9 +188,34 @@ def import_classes(
 
         try:
             new_group = core_models.Group.objects.get(
-                short_name__iexact=short_name, school_term__in=[None, validity_range.school_term],
+                short_name__iexact=short_name,
+                school_term__in=[None, validity_range.school_term],
             )
         except core_models.Group.DoesNotExist:
+            # Determine collisions of long name
+            while core_models.Group.objects.filter(
+                name=name, school_term=validity_range.school_term
+            ).exists():
+                if not get_site_preferences()["untis_mysql__disambiguate_groups_name"]:
+                    # Do not try to disambiguate it not enabled
+                    break
+
+                suffix = f" ({short_name})"
+                if name.endswith(suffix):
+                    # First try, add a counter
+                    name = f"{name} (2)"
+                else:
+                    # Second or more tries, determine last counter, if any
+                    match = re.match(r"^(.*)(\(\d+\))$", name)
+                    if match:
+                        # Counter found, increase
+                        prefix = match.group(1)
+                        counter = int(match.group(2)) + 1
+                        name = f"{prefix}({counter})"
+                    else:
+                        # Counter not found, add one
+                        name = f"{name} (2)"
+
             new_group = core_models.Group.objects.create(
                 short_name=short_name,
                 name=name,
@@ -259,7 +285,8 @@ def import_rooms(validity_range: ValidityRange) -> Dict[int, chronos_models.Room
         logger.info("Import room {} …".format(short_name))
 
         new_room, created = chronos_models.Room.objects.get_or_create(
-            short_name=short_name, defaults={"name": name, "import_ref_untis": import_ref},
+            short_name=short_name,
+            defaults={"name": name, "import_ref_untis": import_ref},
         )
 
         if created:
@@ -546,7 +573,8 @@ def import_absence_reasons(
         logger.info("Import absence reason {} …".format(short_name))
 
         new_reason, created = chronos_models.AbsenceReason.objects.get_or_create(
-            import_ref_untis=import_ref, defaults={"short_name": short_name, "name": name},
+            import_ref_untis=import_ref,
+            defaults={"short_name": short_name, "name": name},
         )
 
         if created:
